@@ -1,6 +1,7 @@
 from collections import defaultdict
 from contextlib import contextmanager
 from datetime import date, datetime, timezone
+import logging
 import re
 import requests
 import requests.adapters
@@ -9,6 +10,7 @@ import time
 import urllib.parse
 from .exceptions import SessionClosedError
 
+logger = logging.getLogger(__name__)
 
 URL_DATE_FORMAT = '%Y%m%d%H%M%S'
 MEMENTO_URL_PATTERN = re.compile(
@@ -47,6 +49,36 @@ def parse_timestamp(time_string):
     """
     Given a Wayback-style timestamp string, return an equivalent ``datetime``.
     """
+    # Before parsing, try to fix invalid timestamps.
+    # We've seen a handful of timestamps where "00" was inserted before the
+    # month or day part of the timestamp, e.g:
+    #
+    #   20000008241731
+    #       ^^ Month is "00"
+    #
+    # The Wayback team looked into some of these, and the "00" was always
+    # an insertion, pushing the month or day and the following components of
+    # the timestamp out by two characters. Then the seconds get truncated
+    # (there's only room for 14 characters in the timestamp in the CDX index).
+    # For example:
+    #
+    #   In raw data:   2000000824173151 (16 characters)
+    #   In CDX index:  20000008241731   (Truncated to 14 characters)
+    #   Correct value: 20000824173151   (Aug. 24, 2000 at 17:31:51 UTC)
+    #
+    # The best we can do for these cases is pull out the incorrect "00" and add
+    # "00" for the seconds that got truncated. This isn't exact, but we can't
+    # see the raw data so this is as close as we can get.
+    #
+    # The issue seems to be limited to some crawls in the year 2000.
+    if time_string[5] == '0' and time_string[4] == '0':
+        logger.warning("found invalid timestamp with month 00: %s", time_string)
+        time_string = f'{time_string[0:4]}{time_string[6:]}00'
+    elif time_string[7] == '0' and time_string[6] == '0':
+        logger.warning("found invalid timestamp with day 00: %s", time_string)
+        time_string = f'{time_string[0:6]}{time_string[8:]}00'
+
+    # Parse the cleaned-up result.
     return (datetime
             .strptime(time_string, URL_DATE_FORMAT)
             .replace(tzinfo=timezone.utc))
@@ -141,9 +173,9 @@ def rate_limited(calls_per_second=2, group='default'):
 
     Parameters
     ----------
-    calls_per_second : float or int, optional
+    calls_per_second : float or int, default: 2
         Maximum number of calls into this context allowed per second
-    group : string, optional
+    group : string, default: 'default'
         Unique name to scope rate limiting. If two contexts have different
         `group` values, their timings will be tracked separately.
     """
